@@ -1,4 +1,8 @@
 #! /usr/bin/env python3
+
+# pylint: disable=invalid-name
+# pylint: disable=duplicate-code
+
 """Sample script for APDU error checking with a custom error checker.
 
 __author__ = "https://www.gemalto.com/"
@@ -32,11 +36,12 @@ from smartcard.sw.SWExceptions import SWException
 
 
 class MyErrorChecker(ErrorChecker):
+    # pylint: disable=too-few-public-methods
     """Our custom error checker that will except if 0x61<sw1<0x70."""
 
     def __call__(self, data, sw1, sw2):
         print(sw1, sw2)
-        if 0x61 < sw1 and 0x70 > sw1:
+        if 0x61 < sw1 < 0x70:
             raise SWException(data, sw1, sw2)
 
 
@@ -45,8 +50,9 @@ GET_RESPONSE = [0xA0, 0xC0, 00, 00]
 SELECT = [0xA0, 0xA4, 0x00, 0x00, 0x02]
 DF_TELECOM = [0x7F, 0x10]
 
-if __name__ == "__main__":
 
+def main():
+    """main"""
     print("Insert a card within 10 seconds")
     print("Cards without a DF_TELECOM will except")
 
@@ -68,12 +74,10 @@ if __name__ == "__main__":
     cardservice.connection.connect()
 
     try:
-        SELECT = [0xA0, 0xA4, 0x00, 0x00, 0x02]
-        DF_TELECOM = [0x7F, 0x10]
         apdu = SELECT + DF_TELECOM
+        # pylint: disable=unused-variable
         response, sw1, sw2 = cardservice.connection.transmit(apdu)
         if sw1 == 0x9F:
-            GET_RESPONSE = [0xA0, 0xC0, 00, 00]
             apdu = GET_RESPONSE + [sw2]
             response, sw1, sw2 = cardservice.connection.transmit(apdu)
     except SWException as e:
@@ -82,6 +86,10 @@ if __name__ == "__main__":
     cardservice.connection.disconnect()
     cardservice.connection.release()
 
+
+if __name__ == "__main__":
+    main()
+
     import sys
 
     if "win32" == sys.platform:
